@@ -16,37 +16,46 @@ class FloatField(Field):
         starting_column: int,
         decimal_digits: int,
         format: str = "F",
+        sep: str = ".",
         value: Optional[float] = None,
     ) -> None:
         super().__init__(size, starting_column, value)
         self.__decimal_digits = decimal_digits
         self.__format = format
+        self.__sep = sep
 
     # Override
     def read(self, line: str) -> Optional[float]:
-        linevalue = line[self._starting_column : self._ending_column].strip()
+        linevalue = (
+            line[self._starting_column : self._ending_column]
+            .strip()
+            .replace(self.__sep, ".")
+        )
         self._value = (
             float(linevalue)
-            if linevalue.replace(".", "").replace(self.__format, "").isdigit()
+            if linevalue.replace(".", "")
+            .replace(self.__format, "")
+            .replace("+", "")
+            .replace("-", "")
+            .isdigit()
             else None
         )
         return self._value
 
     # Override
     def write(self, line: str) -> str:
-        if self.value is None:
-            raise ValueError("Field cannot be written if has no value")
         if len(line) < self._ending_column:
             line = line.ljust(self._ending_column)
         value = ""
-        for d in range(self.__decimal_digits, -1, -1):
-            value = "{:.{d}{format}}".format(
-                round(self.value, d),
-                d=d,
-                format=self.__format,
-            )
-            if len(value) <= self._size:
-                break
+        if self.value is not None:
+            for d in range(self.__decimal_digits, -1, -1):
+                value = "{:.{d}{format}}".format(
+                    round(self.value, d),
+                    d=d,
+                    format=self.__format,
+                )
+                if len(value) <= self._size:
+                    break
 
         return (
             line[: self._starting_column]
