@@ -31,7 +31,7 @@ def test_sectionreading_withdata():
     sr = SectionReading([DummySection])
     m: MagicMock = mock_open(read_data=data + "\n")
     with patch("builtins.open", m):
-        sd = sr.read("", "")
+        sd = sr.read("", "", "utf-8")
         assert not sr.empty
         dbs = [b for b in sd.of_type(DummySection)]
         assert len(dbs) == 1
